
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#ifndef GSSDP_ENUMS_H
#define GSSDP_ENUMS_H

#include <glib-object.h>

G_BEGIN_DECLS
/* enumerations from gssdp-client.h */
GType gssdp_uda_version_get_type (void);
#define GSSDP_TYPE_UDA_VERSION (gssdp_uda_version_get_type())
/* enumerations from gssdp-error.h */
GType gssdp_error_get_type (void);
#define GSSDP_TYPE_ERROR (gssdp_error_get_type())
G_END_DECLS

#endif /* GSSDP_ENUMS_H */

/* Generated data ends here */

